@@ -56,14 +56,14 @@
 
 //***************************************************************************
 Kwave::Track::Track()
-    :m_lock(QMutex::Recursive), m_lock_usage(), m_stripes(), m_selected(true),
+    :m_lock(), m_lock_usage(), m_stripes(), m_selected(true),
      m_uuid(QUuid::createUuid())
 {
 }
 
 //***************************************************************************
 Kwave::Track::Track(sample_index_t length, QUuid *uuid)
-    :m_lock(QMutex::Recursive), m_lock_usage(), m_stripes(), m_selected(true),
+    :m_lock(), m_lock_usage(), m_stripes(), m_selected(true),
      m_uuid((uuid) ? *uuid : QUuid::createUuid())
 {
     if (length <= STRIPE_LENGTH_MAXIMUM) {
